@@ -1,8 +1,8 @@
 use crate::ColorTuple;
 
-/// Default precision used for color comparsion.
+/// Default precision used for color comparison.
 /// It is `0.000_000_001`
-pub static DEFAULT_APPROX_EQ_PRECISION: f64 = 0.000_000_001;
+pub static DEFAULT_APPROX_EQ_PRECISION: f64 = 1e-9;
 
 /// Methods to compare two colors
 pub trait ApproxEq<T> {
@@ -18,7 +18,9 @@ pub fn approx_def(x: f64, y: f64) -> bool {
 }
 
 pub fn approx_tuple(x: &ColorTuple, y: &ColorTuple, precision: f64) -> bool {
-  approx(x.0, y.0, precision) && approx(x.1, y.1, precision) && approx(x.2, y.2, precision)
+  approx(x.0, y.0, precision)
+    && approx(x.1, y.1, precision)
+    && approx(x.2, y.2, precision)
 }
 
 pub fn approx_tuple_def(x: &ColorTuple, y: &ColorTuple) -> bool {
