@@ -1,14 +1,17 @@
-use crate::{ColorTuple,err};
+use crate::{err, ColorTuple};
 use err::{make_parse_err, ParseError};
 
-
 pub fn hex_to_rgb(s: &str) -> Result<ColorTuple, ParseError> {
   let mut hex = s.replace("#", "").to_lowercase();
   let hex_chars = hex.chars().collect::<Vec<char>>();
   let count = hex_chars.len();
 
   if count == 3 {
-    hex = hex_chars.iter().map(|c| c.to_string().repeat(2)).collect::<Vec<String>>().join("");
+    hex = hex_chars
+      .iter()
+      .map(|c| c.to_string().repeat(2))
+      .collect::<Vec<String>>()
+      .join("");
   } else if count != 6 {
     return Err(make_parse_err(s, "hex"));
   }
